# A Histogram is the distribution of a continuous variable
# by dividing into bins, and counting the observations in each bin
#
# key function:  geom_histogram()
# Alternative functions:  stat_bin()
# Position adjustments:  Identity (or position_identity())
#   stack (or position_stack()), dodge (or position_dodge())
#   Default value is stack.
#
# Key arguments to customize the plot:  alpha, color, fill,
#      linetype, size

a<-ggplot(wdata,aes(x=weight))
a + geom_histogram()
a + geom_histogram(bins=50)
# default number of bins is 30.  More gives you smoother dist.

# change line color and fill color  
a + geom_histogram(color="black", fill = "gray")
# add mean line
a + geom_histogram(color="black", fill = "gray") +
  geom_vline(aes(xintercept = mean(weight)),
             color = "#fc4e07",linetype="dashed", size = 1)

# Now let's play with color and grouping
a + geom_histogram(aes(color = sex), fill = "white")
# Notice that there is overlap, because the x-values actually overlap

# Position adjustment:  "identity" (overlaid)
a + geom_histogram(aes(color = sex), fill = "white", alpha = 0.6,
                   position = "identity")
# alpha is transparency, btw
# We made them transparent, because otherwise one would completely
# cover the other, and we couldn't see the dist of both.


# Position = dodge interleaves the two histograms
a + geom_histogram(aes(color = sex), fill = "white",
                   position = "dodge")

# add mean lines
# to do this, we need to calculate the means for each group
library(plyr)
mu <- ddply(wdata, "sex", summarise, grp.mean=mean(weight))
mu
a + geom_histogram(aes(color = sex), fill = "white",
                   position = "dodge") +
  geom_vline(data=mu, aes(xintercept = grp.mean, color = sex),
             linetype = "dashed")

# Use classic theme and change legend position to "top"
# Change outline color manually
a + geom_histogram(aes(color = sex), fill = "white", alpha = 0.4,
                   position = "identity") +
  scale_color_manual(values = c("#00afbb","#e7b800"))

a + geom_histogram(aes(color = sex), fill = "white", alpha = 0.4,
                   position = "identity") +
  scale_color_brewer(palette="Paired")

data(diamonds)
ggplot(diamonds, aes(price)) +
  geom_histogram(binwidth = 500)
ggplot(diamonds, aes(price)) +
  geom_histogram(aes(y = ..density..), binwidth = 500)

# The following two generate the same thing
# except that technically, the second is using a y of density
# instead of count.  However, a histogram discretizes the dist
# into bins, so it's not a "smooth" density plot anyway...
# ..density.. is a "special variable",which is returned 
# by a stat transformation of the original data set. 
# In other words, you are not plotting a variable that is already
# in the data, but rather you are calculating the density
# (or ..count.., and there are others), and plotting that as your aes.


a+  geom_histogram(bins=50)
a+  geom_histogram(aes(y = ..density..),bins=50)

a+  geom_histogram(aes(y = ..count..),bins=50)
# of course, count is the defaut anyway for histogram, so no diff.

# here's another example of using a special variable
# this one plots percentages intsead of raw counts
p <- ggplot(mtcars, aes(x = hp)) +
  geom_bar(aes(y = (..count..)/sum(..count..))
           , binwidth = 25)
p

p1 <- ggplot(mtcars, aes(x = hp)) +
  geom_bar(aes(y = (..count..))
           , binwidth = 25)
p1

# btw, as mentioned earlier, binwidth is no longer a param for bar.

