# several of the examples have been modified from:
# Kassambara:  Guide to Creating Beautiful Graphics in R
# using our "textbook website":
# http://www.sthda.com/english/wiki/be-awesome-in-ggplot2-a-practical-guide-to-be-highly-effective-r-software-and-data-visualization

# and support website:  http://www.sthda.com/english/wiki/ggplot2-essentials

# Part I:
# Review the ppt slides about ggplot (approx slide #14 ff. from Intro-R)
# Requiring the aes and geom in ggplot2 allow a more formal expression of graphics
# also allow a more modular approach
# also allow storing the graphic as an object
# ggplot2 has two main functions for creating plots:
# qplot:  quick plots for simple plots
# ggplot:  for building a plot piece by piece ("layering")
# -->although we will focus on ggplot, many people really like using qplot
# it's fast and easy and generates some good graphs
# it's also a good way to introduce some of concepts used in ggplot

# Part II:  A little less talk, and a lot more action:
#  ggplot2 should already be installed from a prior package dependency
# if not, install.packages("ggplot2")
library(ggplot2)  # to activate the package for this session

# syntax for qplot:   qplot(x, y=NULL, data, geom="auto")
# x, y:  values to plot.  y is optional, depending on plot

# to demonstrate qplot, we'll look at a scatter plot, even though it's 2-dim

# basic scatter plot
qplot(x=mpg, y=wt, data = mtcars, geom="point")

# Use data from numeric vectors (directly from website)
x <- 1:10; y = x*x
# Basic plot
qplot(x,y)
# Add line
qplot(x, y, geom=c("point", "line")) # using both point and line

# Use data from a data frame


data("mtcars")  # this is a built-in dataset in R, so you don't install or library
mtcars  # let's see what it looks like
qplot(mpg, wt, data=mtcars)

# let's look at three of the attributes, and create a data.frame with those 3
mtcarsDF <- mtcars[, c("mpg","cyl", "wt")] #c(rows, columns)
mtcarsDF
class(mtcarsDF$cyl)      # We already know this syntax
class(mtcarsDF[["cyl"]]) # Here is an equialent syntax
class(mtcarsDF["cyl"])   # But this will return "data frame"

# looking at the data, cyl looks numeric.  But there are really 3 discrete classes.
# so let's convert it to a factor:

mtcarsDF$cyl <- as.factor(mtcarsDF$cyl)
class(mtcarsDF$cyl)  # okay, now it shows up as a factor

# scatter plot with smoothed line (note we didn't use param names)
qplot(mpg, wt, data=mtcars, 
      geom =c ("point", "smooth"))

# change the color by a continuous numeric variable (cyl)
qplot(mpg, wt, data=mtcars, color = cyl)
qplot(mpg, wt, data=mtcars, color=cyl, shape=cyl)
# we didn't change cyl to factor in mtcars, only in mtcarsDF
# look at the legend for cyl:  4, 5, 6, 7, 8
# But in reality, there are only 3 values!  (4, 6, 8)

# change the color and shape by groups (factor)
mtcars$cyl <- factor(mtcars$cyl)
qplot(mpg, wt, data=mtcars, color=cyl, shape=cyl)

# change the size of the points according to a continuous variable
# You can do this for size, but not shape, because shapes are distinct objects
qplot(mpg, wt, data=mtcars, color=cyl,size = mpg)


# Now let's backtrack and look at some 1-dim plots
# generate some data containing the weights by sex (M=Male, F=Female)
set.seed (1234)
wdata=data.frame(
  sex=factor(rep(c("F","M"), each=200)),
  weight=c(rnorm(200,55),rnorm(200,58))  # n, mean, [sd]
)

# let's see what was generated
wdata
# basic boxplot from data frame
# change fill color by sex
qplot(sex, weight, data=wdata,
      geom="boxplot")

# Basic Histogram
qplot(weight, data=wdata, geom="histogram")

# Density plot with main titles and axis labels
qplot(weight, data=wdata, geom="density",
      xlab="Weight (kg)", ylab = "Density",
      main = "Density Plot")
# You get the idea.  And now, on to ggplot!!